import { Component, h, Prop, Event, Watch } from '@stencil/core';
import IframeMessenger from '../../services/iframeMessenger';
import IframeSession from '../../services/iframeSession';
export class QuickomChatQrCodeIframe {
  constructor() {
    this.domain = 'https://widget.quickom.com';
    this.qrcode = '';
    this.avatar = '';
    this.name = '';
    this.iframeElement = null;
    this.iframeMessenger = null;
    this.iframeSession = null;
  }
  getUrl() {
    return `${this.domain}/chat`;
  }
  onIframeRef(el) {
    this.iframeElement = el;
  }
  // private reloadIframe() {
  //   if (this.iframeElement) {
  //     this.iframeElement.src = this.getUrl();
  //   }
  // }
  onLoadIframe() {
    this.iframeMessenger = new IframeMessenger(this.iframeElement);
    this.iframeMessenger.start();
    this.iframeSession = IframeSession.init(this.iframeMessenger);
    this.sendChatWithQrCode();
    this.iframeSession.on('message', this.onChatBoxMessage.bind(this));
  }
  sendChatWithQrCode() {
    if (this.iframeSession && this.qrcode) {
      this.iframeSession.send({
        resource: 'chat',
        method: 'chatWithQrCode',
        params: [{ qrcode: this.qrcode, avatar: this.avatar, name: this.name }],
      });
    }
  }
  onChatBoxMessage(data) {
    switch (data.method) {
      case 'show':
        this.visible.emit(true);
        break;
      case 'hide':
        this.visible.emit(false);
        break;
      case 'receiveIncomingCall':
        this.incomingCall.emit(true);
        break;
      case 'cancelIncomingCall':
        this.incomingCall.emit(false);
        break;
    }
  }
  render() {
    return h("iframe", { allow: "camera *;microphone *", class: "relative", onLoad: () => this.onLoadIframe(), ref: el => this.onIframeRef(el), src: this.getUrl(), width: "100%", height: "100%", frameborder: "0" });
  }
  onChangeMemberId() {
    this.sendChatWithQrCode();
  }
  disconnectedCallback() {
    this.iframeSession.destroy();
    this.iframeMessenger.stop();
    this.iframeMessenger = null;
    this.iframeSession = null;
  }
  static get is() { return "quickom-chat-qrcode-iframe"; }
  static get originalStyleUrls() { return {
    "$": ["quickom-chat-qrcode-iframe.css"]
  }; }
  static get styleUrls() { return {
    "$": ["quickom-chat-qrcode-iframe.css"]
  }; }
  static get properties() { return {
    "domain": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "domain",
      "reflect": false,
      "defaultValue": "'https://widget.quickom.com'"
    },
    "qrcode": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "qrcode",
      "reflect": false,
      "defaultValue": "''"
    },
    "avatar": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "avatar",
      "reflect": false,
      "defaultValue": "''"
    },
    "name": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "name",
      "reflect": false,
      "defaultValue": "''"
    }
  }; }
  static get events() { return [{
      "method": "visible",
      "name": "visible",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      }
    }, {
      "method": "incomingCall",
      "name": "incomingCall",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      }
    }]; }
  static get watchers() { return [{
      "propName": "qrcode",
      "methodName": "onChangeMemberId"
    }]; }
}
