import { r as registerInstance, c as createEvent, h } from './index-9cae2eb3.js';
import './_commonjsHelpers-9943807e.js';
import { I as IframeMessenger, a as IframeSession } from './iframeSession-bed47d77.js';

const quickomChatIframeCss = "quickom-chat-iframe{}quickom-chat-iframe iframe{border:1px solid #ebeef5;border-top-right-radius:10px;border-top-left-radius:10px;-webkit-box-shadow:0 2px 12px 0 rgba(0,0,0,.1);box-shadow:0 2px 12px 0 rgba(0,0,0,.1)}";

const QuickomChatIframe = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.visible = createEvent(this, "visible", 7);
    this.incomingCall = createEvent(this, "incomingCall", 7);
    this.domain = 'https://widget.quickom.com';
    this.memberId = '';
    this.chatWithMemberId = '';
    this.avatar = '';
    this.name = '';
    this.apiKey = '';
    this.iframeElement = null;
    this.iframeMessenger = null;
    this.iframeSession = null;
  }
  getUrl() {
    return `${this.domain}/chat`;
  }
  onIframeRef(el) {
    this.iframeElement = el;
  }
  // private reloadIframe() {
  //   if (this.iframeElement) {
  //     this.iframeElement.src = this.getUrl();
  //   }
  // }
  onLoadIframe() {
    this.iframeMessenger = new IframeMessenger(this.iframeElement);
    this.iframeMessenger.start();
    this.iframeSession = IframeSession.init(this.iframeMessenger);
    this.sendChatWithMember();
    this.iframeSession.on('message', this.onChatBoxMessage.bind(this));
  }
  sendChatWithMember() {
    if (this.iframeSession && this.memberId && this.chatWithMemberId && this.apiKey) {
      this.iframeSession.send({
        resource: 'chat',
        method: 'chatWithMember',
        params: [{ memberId: this.memberId, chatWithMemberId: this.chatWithMemberId, apiKey: this.apiKey, avatar: this.avatar, name: this.name }],
      });
    }
  }
  onChatBoxMessage(data) {
    switch (data.method) {
      case 'show':
        this.visible.emit(true);
        break;
      case 'hide':
        this.visible.emit(false);
        break;
      case 'receiveIncomingCall':
        this.incomingCall.emit(true);
        break;
      case 'cancelIncomingCall':
        this.incomingCall.emit(false);
        break;
    }
  }
  render() {
    return h("iframe", { allow: "camera *;microphone *", class: "relative", onLoad: () => this.onLoadIframe(), ref: el => this.onIframeRef(el), src: this.getUrl(), width: "100%", height: "100%", frameborder: "0" });
  }
  onChangeMemberId() {
    this.sendChatWithMember();
  }
  onChangeChatWithMemberId() {
    this.sendChatWithMember();
  }
  onChangeApiKey() {
    this.sendChatWithMember();
  }
  disconnectedCallback() {
    this.iframeSession.destroy();
    this.iframeMessenger.stop();
    this.iframeMessenger = null;
    this.iframeSession = null;
  }
  static get watchers() { return {
    "memberId": ["onChangeMemberId"],
    "chatWithMemberId": ["onChangeChatWithMemberId"],
    "apiKey": ["onChangeApiKey"]
  }; }
};
QuickomChatIframe.style = quickomChatIframeCss;

export { QuickomChatIframe as quickom_chat_iframe };
